"""

    Wrapper around Forecast API

    see https://developer.forecast.io/docs/v2 for furter documentation.

"""

import aiohttp
from collections import namedtuple

__all__ = ['Response', 'RequestHandler']

Response = namedtuple('Response', 'status headers data')


class RequestHandler:

    def __init__(self, timeout=None, connector=None, *, loop=None):
        self.loop = loop
        self.timeout = timeout or 15
        self.session = aiohttp.ClientSession(connector=connector,
                                             loop=self.loop)

    async def get(self, url, params):
        """
        Parameters:
            url (str):
            params (dict):
        Returns:
            Response: response object
        """
        with aiohttp.Timeout(self.timeout):
            async with self.session.get(url, params=params) as response:
                data = await response.json()
                return Response(response.status, response.headers, data)

    def close(self):
        self.session.close()

    def __del__(self):
        self.close()
